.. sha256bit documentation master file, created by
   sphinx-quickstart on Sun May 21 02:49:23 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

sha256bit
=====================================
Pure python implementation of SHA256 with features which are often lacking:

- bit granularity for message input length
- import/export API to "persist" the state in the middle of a hash computation

Other online resources:

- `project page on GitHub`_
- `Download Page`_ with releases
- This page, when viewed online is at https://sha256bit.readthedocs.io/en/latest/

.. _`project page on GitHub`: https://github.com/sebastien-riou/sha256bit
.. _`Download Page`: http://pypi.python.org/pypi/sha256bit


.. toctree::
  :maxdepth: 4

  installation
  examples_python3
  api



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
